@@ -20,10 +20,10 @@ startworkpath = os.getcwd() + '/'
 
 os.chdir(os.path.dirname(__file__))
 
-__version__ = '0.1.2.4'
+__version__ = '0.1.2.7'
 
 
-click.echo('Welcome to Stuoe ' + __version__) 
+click.echo('Welcome to Stuoe ' + __version__)
 click.echo('Worker in ' + os.getcwd())
 click.echo('')
 
@@ -52,6 +52,7 @@ def run(port):
 @click.option("--name", default='Dafault', help="Start A New Project", type=str)
 def startproject(name):
     if not os.path.exists(startworkpath + name):
+        os.makedirs(startworkpath + name)
         click.echo('Create  ' + startworkpath + name)
     if not os.listdir(startworkpath + name) == []:
         click.echo('目录为' + startworkpath + name + '的文件夹并不为空，无法创建新的工程')
@@ -61,6 +62,7 @@ def startproject(name):
     click.echo('项目已经成功创建 ')
     exit()
 
+
 @click.command()
 @click.option("--name", default='Dafault', help="A Update", type=str)
 def update(name):
@@ -75,6 +77,7 @@ def update(name):
     click.echo('项目已经成功更新 ')
     exit()
 
+
 '''
 @click.command()
 @click.option("--host", default='0.0.0.0', help="Runing Server Host", type=str)
@@ -91,6 +94,8 @@ def runserver(host,port,debug):
     app.app.run(host=host,port=port,debug=debug)
 
 '''
+
+
 def copy_Templates_to_newproject(copypath=os.getcwd(), pastpath=os.getcwd() + '/paster/'):
     for i in os.listdir(copypath):
         if not (i == '__init__.py' or i == 'server.conf' or i == 'sqlite3.db'):
@@ -111,3 +116,24 @@ def copy_Templates_to_newproject(copypath=os.getcwd(), pastpath=os.getcwd() + '/
 cli.add_command(run)
 cli.add_command(startproject)
 cli.add_command(update)
+
+
+# EXTENSIONS COMPENMENT
+class EXTENSIONS(object):
+    '''
+    父类EXTENSIONS覆盖了编写插件的大部分工作
+    '''
+
+    def __init__(self, NAME, URL, VERISON, DESCRIBE, AUTHOR,MAIN=''):
+        self.NAME = NAME
+        self.URL = URL
+        self.VERSION = VERISON
+        self.DESCRIBE = DESCRIBE
+        self.AUTHOR = AUTHOR
+        
+
+    def register_for_app(self, APP):
+        self.app = app
+
+    def add_url_rule(self, URL, RULE):
+        self.APP.add_url_rule(URL, view_func=RULE)
